@@ -5,7 +5,7 @@ from typing import Any, Dict
 import joblib
 
 from baseten_scaffolding.constants import SKLEARN
-from baseten_scaffolding.definitions.base import WrittenModelScaffoldDefinition, prediction_flow
+from baseten_scaffolding.definitions.base import WrittenModelScaffoldDefinition
 from baseten_scaffolding.model_inference import infer_sklearn_packages, parse_requirements_file
 
 
